@@ -122,27 +122,27 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
             closest_time, reverse = find_prev_closest_time(prompt_time, subset_time_series)
 
-            if get_min_diff(prompt_time, closest_time) < 5:
-                screen_event = list(df_logs_combined[df_logs_combined['LOG_TIME_DATETIME'] == closest_time][
-                                        "PHONE_EVENT"])[0]
+            # if get_min_diff(prompt_time, closest_time) < 5:
+            screen_event = list(df_logs_combined[df_logs_combined['LOG_TIME_DATETIME'] == closest_time][
+                                    "PHONE_EVENT"])[0]
 
-                # to determine screen on/off
-                if not reverse:
-                    if screen_event == "PHONE_SCREEN_ON":
-                        screen_status = "Screen On"
-                    elif screen_event == "PHONE_SCREEN_OFF":
-                        screen_status = "Screen Off"
-                    else:
-                        screen_status = "NF"
+            # to determine screen on/off
+            if not reverse:
+                if screen_event == "PHONE_SCREEN_ON":
+                    screen_status = "Screen On"
+                elif screen_event == "PHONE_SCREEN_OFF":
+                    screen_status = "Screen Off"
                 else:
-                    if screen_event == "PHONE_SCREEN_ON":
-                        screen_status = "Screen Off"
-                    elif screen_event == "PHONE_SCREEN_OFF":
-                        screen_status = "Screen On"
-                    else:
-                        screen_status = "NF"
+                    screen_status = "NF"
             else:
-                screen_status = "NF"
+                if screen_event == "PHONE_SCREEN_ON":
+                    screen_status = "Screen Off"
+                elif screen_event == "PHONE_SCREEN_OFF":
+                    screen_status = "Screen On"
+                else:
+                    screen_status = "NF"
+            # else:
+            #     screen_status = "NF"
 
         matched_time_list.append(closest_time)
         matched_result_list.append(screen_status)
