@@ -31,14 +31,14 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
         # target date
         validated_date_list.append(date_in_study)
 
-        # # 1 day after target date
-        # date_format = "%Y-%m-%d"
-        # one_date_after_datetime = datetime.strptime(date_in_study, date_format).date() + timedelta(days=1)
-        # one_date_after = one_date_after_datetime.strftime(date_format)
-        # date_folder_path = intermediate_participant_path + sep + one_date_after
-        # one_day_after_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
-        # if len(one_day_after_log_paths) != 0:
-        #     validated_date_list.append(one_date_after)
+        # 1 day after target date
+        date_format = "%Y-%m-%d"
+        one_date_after_datetime = datetime.strptime(date_in_study, date_format).date() + timedelta(days=1)
+        one_date_after = one_date_after_datetime.strftime(date_format)
+        date_folder_path = intermediate_participant_path + sep + one_date_after
+        one_day_after_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
+        if len(one_day_after_log_paths) != 0:
+            validated_date_list.append(one_date_after)
 
 
     return validated_date_list
