@@ -48,7 +48,7 @@ def clean_dataframe(df):
     df.reset_index(inplace=True, drop=True)
     dropped_rows = []
     for idx in df.index:
-        local_time_str = df["Local_Time"][idx]
+        local_time_str = df["HEADER_TIME_STAMP"][idx]
         if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3 or len(local_time_str.split('-')[0]) > 4:
             dropped_rows.append(idx)
     df = df.drop(dropped_rows)
@@ -129,14 +129,14 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
             closest_time = find_closest_time(prompt_time, subset_time_list)
 
             # check if matched time is 5 minutes away from prompt time
-            if get_min_diff(prompt_time, closest_time) < 5:
-                battery_level = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
-                                         "BATTERY_LEVEL"])[0]
-                charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
-                                           "BATTERY_CHARGING"])[0]
-            else:
-                battery_level = "NF"
-                charging_status = "NF"
+            # if get_min_diff(prompt_time, closest_time) < 5:
+            battery_level = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
+                                     "BATTERY_LEVEL"])[0]
+            charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
+                                       "BATTERY_CHARGING"])[0]
+            # else:
+            #     battery_level = "NF"
+            #     charging_status = "NF"
 
 
         matched_time_list.append(closest_time)
